@@ -87,6 +87,10 @@ class PortCommon(object):
     Mixin with common things for input and output ports.
     """
     def _open(self, **kwargs):
+        if 'virtual' in kwargs:
+            raise IOError(
+                "virtual ports are not supported by the PortMIDI backend")
+
         self._stream = pm.PortMidiStreamPtr()
 
         opening_input = hasattr(self, 'receive')
