@@ -13,9 +13,9 @@ Todo:
 from __future__ import print_function, division
 import sys
 import math
+import struct
 from contextlib import contextmanager
 from .messages import BaseMessage, check_time
-from .types import signed, unsigned, encode_variable_int
 
 PY2 = (sys.version_info.major == 2)
 
@@ -67,12 +67,79 @@ _smpte_framerate_decode = {
     }
 _smpte_framerate_encode = reverse_table(_smpte_framerate_decode)
 
+def signed(to_type, n):
+    formats = {
+        'byte': 'Bb',
+        'short': 'Hh',
+        'long': 'Ll',
+        'ubyte': 'bB',
+        'ushort': 'hH',
+        'ulong': 'lL',
+        }
+
+    try:
+        pack_format, unpack_format = formats[to_type]
+    except KeyError:
+        raise ValueError('invalid integer type {}'.format(to_type))
+
+    try:
+        packed = struct.pack(pack_format, n)
+        return struct.unpack(unpack_format, packed)[0]
+    except struct.error as err:
+        raise ValueError(*err.args)
+
+def unsigned(to_type, n):
+    return signed('u{}'.format(to_type), n)
+
+def encode_variable_int(value):
+    """Encode variable length integer.
+
+    Returns the integer as a list of bytes,
+    where the last byte is < 128.
+
+    This is used for delta times and meta message payload
+    length.
+    """
+    if not isinstance(value, int) or value < 0:
+        raise ValueError('variable int must be a positive integer')
+
+    bytes = []
+    while value:
+        bytes.append(value & 0x7f)
+        value >>= 7
+
+    if bytes:
+        bytes.reverse()
+
+        # Set high bit in every byte but the last.
+        for i in range(len(bytes) - 1):
+            bytes[i] |= 0x80
+        return bytes
+    else:
+        return [0]
+
 def encode_string(string):
     return list(bytearray(string.encode(_charset)))
 
 def decode_string(data):
     return bytearray(data).decode(_charset)
 
+def bpm2tempo(bpm):
+    """Convert beats per minute to MIDI file tempo.
+
+    Returns microseconds per beat as an integer."""
+    # 120 => 500000
+    # 60 => 1000000
+    return int(bpm * (250000.0 / 60))
+
+def tempo2bpm(tempo):
+    """Convert MIDI file tempo to BPM.
+
+    Returns BPM as an integer or float."""
+    # 500000 => 120
+    # 1000000 => 60
+    return tempo / (250000.0 / 60)
+
 @contextmanager
 def meta_charset(tmp_charset):
     global _charset
