@@ -167,7 +167,7 @@ class BaseInput(BasePort):
         If block=False is passed, None will be returned if there are no
         pending messages or if the port is closed.
         """
-        if self.callback:
+        if hasattr(self, 'callback') and self.callback:
             raise IOError('a callback is currently set for this port')
 
         # If there is a message pending, return it right away.
